@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,10 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcdn.endpoint import endpoint_data
+
 class AddLiveAppSnapshotConfigRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'AddLiveAppSnapshotConfig')
+		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_TimeInterval(self):
 		return self.get_query_params().get('TimeInterval')
@@ -29,11 +37,11 @@ class AddLiveAppSnapshotConfigRequest(RpcRequest):
 	def set_TimeInterval(self,TimeInterval):
 		self.add_query_param('TimeInterval',TimeInterval)
 
-	def get_OssBucket(self):
-		return self.get_query_params().get('OssBucket')
+	def get_OssEndpoint(self):
+		return self.get_query_params().get('OssEndpoint')
 
-	def set_OssBucket(self,OssBucket):
-		self.add_query_param('OssBucket',OssBucket)
+	def set_OssEndpoint(self,OssEndpoint):
+		self.add_query_param('OssEndpoint',OssEndpoint)
 
 	def get_AppName(self):
 		return self.get_query_params().get('AppName')
@@ -47,30 +55,30 @@ class AddLiveAppSnapshotConfigRequest(RpcRequest):
 	def set_SecurityToken(self,SecurityToken):
 		self.add_query_param('SecurityToken',SecurityToken)
 
+	def get_OverwriteOssObject(self):
+		return self.get_query_params().get('OverwriteOssObject')
+
+	def set_OverwriteOssObject(self,OverwriteOssObject):
+		self.add_query_param('OverwriteOssObject',OverwriteOssObject)
+
+	def get_OssBucket(self):
+		return self.get_query_params().get('OssBucket')
+
+	def set_OssBucket(self,OssBucket):
+		self.add_query_param('OssBucket',OssBucket)
+
 	def get_DomainName(self):
 		return self.get_query_params().get('DomainName')
 
 	def set_DomainName(self,DomainName):
 		self.add_query_param('DomainName',DomainName)
 
-	def get_OssEndpoint(self):
-		return self.get_query_params().get('OssEndpoint')
-
-	def set_OssEndpoint(self,OssEndpoint):
-		self.add_query_param('OssEndpoint',OssEndpoint)
-
 	def get_SequenceOssObject(self):
 		return self.get_query_params().get('SequenceOssObject')
 
 	def set_SequenceOssObject(self,SequenceOssObject):
 		self.add_query_param('SequenceOssObject',SequenceOssObject)
 
-	def get_OverwriteOssObject(self):
-		return self.get_query_params().get('OverwriteOssObject')
-
-	def set_OverwriteOssObject(self,OverwriteOssObject):
-		self.add_query_param('OverwriteOssObject',OverwriteOssObject)
-
 	def get_OwnerId(self):
 		return self.get_query_params().get('OwnerId')
 
